from __future__ import annotations
import frenetix._frenetix
from . import cost_functions
from . import feasability_functions
__all__ = ['ComputeInitialState', 'CostStrategy', 'FeasabilityStrategy', 'FillCoordinates', 'TrajectoryStrategy', 'cost_functions', 'feasability_functions']
class ComputeInitialState(TrajectoryStrategy):
    def __init__(self, coordinateSystem: frenetix._frenetix.CoordinateSystemWrapper, wheelBase: float, steeringAngle: float, lowVelocityMode: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CostStrategy(TrajectoryStrategy):
    pass
class FeasabilityStrategy(TrajectoryStrategy):
    pass
class FillCoordinates(TrajectoryStrategy):
    def __init__(self, lowVelocityMode: bool, initialOrientation: float, coordinateSystem: frenetix._frenetix.CoordinateSystemWrapper, horizon: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class TrajectoryStrategy:
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
    @property
    def name(self) -> str:
        ...



from __future__ import annotations
from frenetix._frenetix import CartesianSample
from frenetix._frenetix import CoordinateSystemWrapper
from frenetix._frenetix import CurviLinearSample
from frenetix._frenetix import PoseWithCovariance
from frenetix._frenetix import PredictedObject
from frenetix._frenetix import QuarticTrajectory
from frenetix._frenetix import QuinticTrajectory
from frenetix._frenetix import TrajectoryHandler
from frenetix._frenetix import TrajectorySample
from frenetix._frenetix import trajectory_functions
from . import _frenetix
__all__: tuple = ('CartesianSample', 'CoordinateSystemWrapper', 'CurviLinearSample', 'PoseWithCovariance', 'PredictedObject', 'QuarticTrajectory', 'QuinticTrajectory', 'TrajectoryHandler', 'TrajectorySample', 'trajectory_functions')



from ._frenetix import (
    CartesianSample,
    CoordinateSystemWrapper, CurviLinearSample,
    QuarticTrajectory, QuinticTrajectory,
    PoseWithCovariance, PredictedObject,
    TrajectoryHandler,
    TrajectorySample,
    PlannerState,
    CartesianPlannerState,
    CurvilinearPlannerState,
    trajectory_functions
)

__all__ = (
    "CartesianSample",
    "CoordinateSystemWrapper",
    "CurviLinearSample",
    "PoseWithCovariance",
    "PredictedObject",
    "QuarticTrajectory",
    "QuinticTrajectory",
    "TrajectoryHandler",
    "TrajectorySample",
    "PlannerState",
    "CartesianPlannerState",
    "CurvilinearPlannerState",
    "trajectory_functions"
)




from __future__ import annotations
import numpy
import pybind11_stubgen.typing_ext
import typing
from . import trajectory_functions
__all__ = ['CartesianSample', 'CoordinateSystemWrapper', 'CurviLinearSample', 'InvalidCovarianceMatrixError', 'PoseWithCovariance', 'PredictedObject', 'QuarticTrajectory', 'QuinticTrajectory', 'TrajectoryHandler', 'TrajectorySample', 'trajectory_functions']
class CartesianSample:
    is_initialized: bool
    def __getstate__(self) -> dict:
        ...
    @typing.overload
    def __init__(self) -> None:
        ...
    @typing.overload
    def __init__(self, x: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], y: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], theta_gl: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], v: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], a: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], kappa_gl: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], kappa_dot: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def a(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @a.setter
    def a(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def kappa(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @kappa.setter
    def kappa(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def kappa_dot(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @kappa_dot.setter
    def kappa_dot(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def theta(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @theta.setter
    def theta(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def v(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @v.setter
    def v(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def x(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @x.setter
    def x(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def y(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @y.setter
    def y(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
class CoordinateSystemWrapper:
    ref_line: list[typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(2, 1)]]
    def __getstate__(self) -> dict:
        ...
    def __init__(self, ref_path: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 'n'), numpy.ndarray.flags.writeable, numpy.ndarray.flags.c_contiguous]) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    @property
    def ref_curv(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @ref_curv.setter
    def ref_curv(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def ref_curv_d(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @ref_curv_d.setter
    def ref_curv_d(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def ref_curv_dd(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @ref_curv_dd.setter
    def ref_curv_dd(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def ref_pos(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @ref_pos.setter
    def ref_pos(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def ref_theta(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @ref_theta.setter
    def ref_theta(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
class CurviLinearSample:
    is_initialized: bool
    def __getstate__(self) -> dict:
        ...
    @typing.overload
    def __init__(self) -> None:
        ...
    @typing.overload
    def __init__(self, s: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], d: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], theta_gl: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], dd: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], ddd: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], ss: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable], sss: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def d(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @d.setter
    def d(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def d_ddot(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @d_ddot.setter
    def d_ddot(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def d_dot(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @d_dot.setter
    def d_dot(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def s(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @s.setter
    def s(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def s_ddot(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @s_ddot.setter
    def s_ddot(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def s_dot(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @s_dot.setter
    def s_dot(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
    @property
    def theta(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @theta.setter
    def theta(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...
class InvalidCovarianceMatrixError(ValueError):
    pass
class PoseWithCovariance:
    def __init__(self, arg0: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)], arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(4, 1)], arg2: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(6, 6)]) -> None:
        ...
    def __repr__(self) -> str:
        ...
    @property
    def covariance(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(6, 6)]:
        ...
    @property
    def orientation(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(4, 1), numpy.ndarray.flags.writeable]:
        ...
    @property
    def position(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)]:
        ...
class PredictedObject:
    def __init__(self, arg0: int, arg1: list[PoseWithCovariance], arg2: float, arg3: float) -> None:
        ...
    def __repr__(self) -> str:
        ...
    @property
    def length(self) -> float:
        ...
    @property
    def object_id(self) -> int:
        ...
    @property
    def predictedPath(self) -> list[PoseWithCovariance]:
        ...
    @property
    def width(self) -> float:
        ...
class QuarticTrajectory:
    def __call__(self, arg0: typing.Annotated[numpy.ndarray, numpy.float64], arg1: typing.Annotated[numpy.ndarray, numpy.float64]) -> typing.Any:
        ...
    def __getstate__(self) -> dict:
        ...
    def __init__(self, tau_0: float, delta_tau: float, x_0: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)], x_d: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(2, 1)], x_0_order: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)] = ..., x_d_order: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(2, 1)] = ...) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    def squared_jerk_integral(self, arg0: float) -> float:
        ...
    @property
    def coeffs(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(5, 1)]:
        ...
    @property
    def delta_tau(self) -> float:
        ...
class QuinticTrajectory:
    def __call__(self, arg0: typing.Annotated[numpy.ndarray, numpy.float64], arg1: typing.Annotated[numpy.ndarray, numpy.float64]) -> typing.Any:
        ...
    def __getstate__(self) -> dict:
        ...
    def __init__(self, tau_0: float, delta_tau: float, x_0: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)], x_d: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)], x_0_order: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)] = ..., x_d_order: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)] = ...) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    def squared_jerk_integral(self, arg0: float) -> float:
        ...
    @property
    def coeffs(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(6, 1)]:
        ...
    @property
    def delta_tau(self) -> float:
        ...
class TrajectoryHandler:
    def __init__(self, dt: float) -> None:
        ...
    def add_cost_function(self, arg0: trajectory_functions.CostStrategy) -> None:
        ...
    def add_feasability_function(self, arg0: trajectory_functions.FeasabilityStrategy) -> None:
        ...
    def add_function(self, arg0: trajectory_functions.TrajectoryStrategy) -> None:
        ...
    def clear_cost_functions(self) -> None:
        """
        Clears all cost functions.
        """
    def evaluate_all_current_functions(self, calculateAllCosts: bool = False) -> None:
        ...
    def evaluate_all_current_functions_concurrent(self, calculateAllCosts: bool = False) -> None:
        ...
    def generate_trajectories(self, samplingMatrix: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 'n'), numpy.ndarray.flags.writeable, numpy.ndarray.flags.c_contiguous], lowVelocityMode: bool) -> None:
        ...
    def get_cost_functions(self) -> typing.Iterator:
        ...
    def get_feasability_functions(self) -> typing.Iterator:
        ...
    def get_other_functions(self) -> typing.Iterator:
        ...
    def get_sorted_trajectories(self) -> typing.Iterator:
        ...
    def reset_Trajectories(self) -> None:
        """
        Resets the trajectories container.
        """
    def set_all_cost_weights_to_zero(self) -> None:
        """
        Sets all cost function weights to zero.
        """
    def sort(self) -> None:
        ...
class TrajectorySample:
    _coll_detected: bool | None
    _cost: float
    _ego_risk: float | None
    _harm_occ_module: float | None
    _obst_risk: float | None
    boundary_harm: float | None
    cartesian: CartesianSample
    cost: float
    costMap: dict[str, tuple[float, float]]
    curvilinear: CurviLinearSample
    dt: float
    feasabilityMap: dict[str, float]
    feasible: bool
    harm_occ_module: float | None
    trajectory_lat: QuinticTrajectory
    trajectory_long: QuarticTrajectory
    uniqueId: int | None
    valid: bool
    def __getstate__(self) -> dict:
        ...
    @typing.overload
    def __init__(self, dt: float, trajectoryLongitudinal: QuarticTrajectory, trajectoryLateral: QuinticTrajectory, uniqueId: int) -> None:
        ...
    @typing.overload
    def __init__(self, x0: float, y0: float, orientation0: float, acceleration0: float, velocity0: float) -> None:
        ...
    def __setstate__(self, arg0: dict) -> None:
        ...
    def add_cost_value_to_list(self, cost_function_name: str, cost: float, weighted_costs: float) -> None:
        """
        Add a cost value to the list of cost values. This includes the weighted and unweighted cost.
        """
    @property
    def sampling_parameters(self) -> typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1), numpy.ndarray.flags.writeable]:
        ...
    @sampling_parameters.setter
    def sampling_parameters(self, arg1: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 1)]) -> None:
        ...



import frenetix._frenetix as _frenetix
from frenetix._frenetix.trajectory_functions.feasability_functions import CheckAccelerationConstraint as CheckAccelerationConstraint, CheckCurvatureConstraint as CheckCurvatureConstraint, CheckCurvatureRateConstraint as CheckCurvatureRateConstraint, CheckVelocityConstraint as CheckVelocityConstraint, CheckYawRateConstraint as CheckYawRateConstraint

__all__ = ['CheckAccelerationConstraint', 'CheckCurvatureConstraint', 'CheckCurvatureRateConstraint', 'CheckVelocityConstraint', 'CheckYawRateConstraint', '__doc__', '__loader__', '__name__', '__package__', '__spec__']

# Names in __all__ with no definition:
#   CheckAccelerationConstraint
#   CheckCurvatureConstraint
#   CheckCurvatureRateConstraint
#   CheckVelocityConstraint
#   CheckYawRateConstraint
#   __doc__
#   __loader__
#   __name__
#   __package__
#   __spec__



import frenetix._frenetix as _frenetix
from frenetix._frenetix.trajectory_functions.cost_functions import CalculateAccelerationCost as CalculateAccelerationCost, CalculateCollisionProbabilityFast as CalculateCollisionProbabilityFast, CalculateCollisionProbabilityMahalanobis as CalculateCollisionProbabilityMahalanobis, CalculateDistanceToObstacleCost as CalculateDistanceToObstacleCost, CalculateDistanceToReferencePathCost as CalculateDistanceToReferencePathCost, CalculateJerkCost as CalculateJerkCost, CalculateLaneCenterOffsetCost as CalculateLaneCenterOffsetCost, CalculateLateralJerkCost as CalculateLateralJerkCost, CalculateLongitudinalJerkCost as CalculateLongitudinalJerkCost, CalculateLongitudinalVelocityCost as CalculateLongitudinalVelocityCost, CalculateOrientationOffsetCost as CalculateOrientationOffsetCost, CalculateSteeringAngleCost as CalculateSteeringAngleCost, CalculateSteeringRateCost as CalculateSteeringRateCost, CalculateVelocityOffsetCost as CalculateVelocityOffsetCost, CalculateYawCost as CalculateYawCost

__all__ = ['CalculateAccelerationCost', 'CalculateCollisionProbabilityFast', 'CalculateCollisionProbabilityMahalanobis', 'CalculateDistanceToObstacleCost', 'CalculateDistanceToReferencePathCost', 'CalculateJerkCost', 'CalculateLaneCenterOffsetCost', 'CalculateLateralJerkCost', 'CalculateLongitudinalJerkCost', 'CalculateLongitudinalVelocityCost', 'CalculateOrientationOffsetCost', 'CalculateSteeringAngleCost', 'CalculateSteeringRateCost', 'CalculateVelocityOffsetCost', 'CalculateYawCost', '__doc__', '__loader__', '__name__', '__package__', '__spec__']

# Names in __all__ with no definition:
#   CalculateAccelerationCost
#   CalculateCollisionProbabilityFast
#   CalculateCollisionProbabilityMahalanobis
#   CalculateDistanceToObstacleCost
#   CalculateDistanceToReferencePathCost
#   CalculateJerkCost
#   CalculateLaneCenterOffsetCost
#   CalculateLateralJerkCost
#   CalculateLongitudinalJerkCost
#   CalculateLongitudinalVelocityCost
#   CalculateOrientationOffsetCost
#   CalculateSteeringAngleCost
#   CalculateSteeringRateCost
#   CalculateVelocityOffsetCost
#   CalculateYawCost
#   __doc__
#   __loader__
#   __name__
#   __package__
#   __spec__



from __future__ import annotations
import frenetix._frenetix
import frenetix._frenetix.trajectory_functions
__all__ = ['CheckAccelerationConstraint', 'CheckCurvatureConstraint', 'CheckCurvatureRateConstraint', 'CheckVelocityConstraint', 'CheckYawRateConstraint']
class CheckAccelerationConstraint(frenetix._frenetix.trajectory_functions.FeasabilityStrategy):
    def __init__(self, switchingVelocity: float, maxAcceleration: float, wholeTrajectory: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CheckCurvatureConstraint(frenetix._frenetix.trajectory_functions.FeasabilityStrategy):
    def __init__(self, deltaMax: float, wheelbase: float, wholeTrajectory: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CheckCurvatureRateConstraint(frenetix._frenetix.trajectory_functions.FeasabilityStrategy):
    def __init__(self, wheelbase: float, velocityDeltaMax: float, wholeTrajectory: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CheckVelocityConstraint(frenetix._frenetix.trajectory_functions.FeasabilityStrategy):
    def __init__(self, wholeTrajectory: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CheckYawRateConstraint(frenetix._frenetix.trajectory_functions.FeasabilityStrategy):
    def __init__(self, deltaMax: float, wheelbase: float, wholeTrajectory: bool) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...



from ... import _frenetix
#import trajectory_functions

__all__ = []

for function_name in dir(_frenetix.trajectory_functions.feasability_functions):
    globals().update({function_name: getattr(_frenetix.trajectory_functions.feasability_functions, function_name)})
    __all__.append(function_name)




import frenetix._frenetix.trajectory_functions as trajectory_functions
import frenetix._frenetix.trajectory_functions.cost_functions as cost_functions
import frenetix._frenetix.trajectory_functions.feasability_functions as feasability_functions
from frenetix._frenetix.trajectory_functions import ComputeInitialState as ComputeInitialState, CostStrategy as CostStrategy, FeasabilityStrategy as FeasabilityStrategy, FillCoordinates as FillCoordinates, TrajectoryStrategy as TrajectoryStrategy

__all__ = ['ComputeInitialState', 'CostStrategy', 'FeasabilityStrategy', 'FillCoordinates', 'TrajectoryStrategy', '__doc__', '__loader__', '__name__', '__package__', '__spec__', 'cost_functions', 'feasability_functions']

# Names in __all__ with no definition:
#   ComputeInitialState
#   CostStrategy
#   FeasabilityStrategy
#   FillCoordinates
#   TrajectoryStrategy
#   __doc__
#   __loader__
#   __name__
#   __package__
#   __spec__
#   cost_functions
#   feasability_functions



from ... import _frenetix
from ..._frenetix import TrajectorySample, PredictedObject

__all__ = ["TrajectorySample", "PredictedObject"]

for function_name in dir(_frenetix.trajectory_functions.cost_functions):
    globals().update({function_name: getattr(_frenetix.trajectory_functions.cost_functions, function_name)})
    __all__.append(function_name)




from __future__ import annotations
import frenetix._frenetix
import frenetix._frenetix.trajectory_functions
import numpy
import pybind11_stubgen.typing_ext
import typing
__all__ = ['CalculateAccelerationCost', 'CalculateCollisionProbabilityFast', 'CalculateCollisionProbabilityMahalanobis', 'CalculateDistanceToObstacleCost', 'CalculateDistanceToReferencePathCost', 'CalculateJerkCost', 'CalculateLaneCenterOffsetCost', 'CalculateLateralJerkCost', 'CalculateLongitudinalJerkCost', 'CalculateLongitudinalVelocityCost', 'CalculateOrientationOffsetCost', 'CalculateSteeringAngleCost', 'CalculateSteeringRateCost', 'CalculateVelocityOffsetCost', 'CalculateYawCost']
class CalculateAccelerationCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateCollisionProbabilityFast(frenetix._frenetix.trajectory_functions.CostStrategy):
    @typing.overload
    def __init__(self, function_name: str, cost_weight: float, predictions: dict[int, frenetix._frenetix.PredictedObject], vehicleLength: float, vehicleWidth: float) -> None:
        ...
    @typing.overload
    def __init__(self, function_name: str, cost_weight: float, predictions: dict[int, frenetix._frenetix.PredictedObject], vehicle_length: float, vehicle_width: float, wheelbase_rear: float, off_center_weight: float = 0.5) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
    def printPredictions(self) -> None:
        ...
class CalculateCollisionProbabilityMahalanobis(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float, predictions: dict[int, frenetix._frenetix.PredictedObject]) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateDistanceToObstacleCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float, obstacles: typing.Annotated[numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.DynamicSize('m', 'n'), numpy.ndarray.flags.writeable, numpy.ndarray.flags.c_contiguous]) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateDistanceToReferencePathCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateJerkCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateLaneCenterOffsetCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateLateralJerkCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateLongitudinalJerkCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateLongitudinalVelocityCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateOrientationOffsetCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateSteeringAngleCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateSteeringRateCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateVelocityOffsetCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float, desiredSpeed: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
class CalculateYawCost(frenetix._frenetix.trajectory_functions.CostStrategy):
    def __init__(self, function_name: str, cost_weight: float) -> None:
        ...
    def evaluate_trajectory(self, trajectory: frenetix._frenetix.TrajectorySample) -> None:
        ...
